Rename tpm_chip_find_get() to tpm_get_ops(). This now matches
the name of its counter part tpm_put_ops() better.

Signed-off-by: Stefan Berger <stef...@linux.vnet.ibm.com>
---
 drivers/char/tpm/tpm-chip.c      |  4 ++--
 drivers/char/tpm/tpm-interface.c | 14 +++++++-------
 drivers/char/tpm/tpm.h           |  2 +-
 3 files changed, 10 insertions(+), 10 deletions(-)

diff --git a/drivers/char/tpm/tpm-interface.c b/drivers/char/tpm/tpm-interface.c
index c43a9e28995e..fde731df838b 100644
--- a/drivers/char/tpm/tpm-interface.c
+++ b/drivers/char/tpm/tpm-interface.c
@@ -929,7 +929,7 @@ int tpm_is_tpm2(struct tpm_chip *chip)
 {
        int rc;
 
-       chip = tpm_chip_find_get(chip);
+       chip = tpm_get_ops(chip);
        if (!chip)
                return -ENODEV;
 
@@ -953,7 +953,7 @@ int tpm_pcr_read(struct tpm_chip *chip, int pcr_idx, u8 
*res_buf)
 {
        int rc;
 
-       chip = tpm_chip_find_get(chip);
+       chip = tpm_get_ops(chip);
        if (!chip)
                return -ENODEV;
        if (chip->flags & TPM_CHIP_FLAG_TPM2)
@@ -1012,7 +1012,7 @@ int tpm_pcr_extend(struct tpm_chip *chip, int pcr_idx, 
const u8 *hash)
        u32 count = 0;
        int i;
 
-       chip = tpm_chip_find_get(chip);
+       chip = tpm_get_ops(chip);
        if (!chip)
                return -ENODEV;
 
@@ -1141,7 +1141,7 @@ int tpm_send(struct tpm_chip *chip, void *cmd, size_t 
buflen)
 {
        int rc;
 
-       chip = tpm_chip_find_get(chip);
+       chip = tpm_get_ops(chip);
        if (!chip)
                return -ENODEV;
 
@@ -1261,7 +1261,7 @@ int tpm_get_random(struct tpm_chip *chip, u8 *out, size_t 
max)
        if (!out || !num_bytes || max > TPM_MAX_RNG_DATA)
                return -EINVAL;
 
-       chip = tpm_chip_find_get(chip);
+       chip = tpm_get_ops(chip);
        if (!chip)
                return -ENODEV;
 
@@ -1323,7 +1323,7 @@ int tpm_seal_trusted(struct tpm_chip *chip, struct 
trusted_key_payload *payload,
 {
        int rc;
 
-       chip = tpm_chip_find_get(chip);
+       chip = tpm_get_ops(chip);
        if (!chip || !(chip->flags & TPM_CHIP_FLAG_TPM2))
                return -ENODEV;
 
@@ -1351,7 +1351,7 @@ int tpm_unseal_trusted(struct tpm_chip *chip,
 {
        int rc;
 
-       chip = tpm_chip_find_get(chip);
+       chip = tpm_get_ops(chip);
        if (!chip || !(chip->flags & TPM_CHIP_FLAG_TPM2))
                return -ENODEV;
 
diff --git a/drivers/char/tpm/tpm.h b/drivers/char/tpm/tpm.h
index 7f2d0f489e9c..9d2ad67778b5 100644
--- a/drivers/char/tpm/tpm.h
+++ b/drivers/char/tpm/tpm.h
@@ -535,7 +535,7 @@ static inline void tpm_msleep(unsigned int delay_msec)
                     delay_msec * 1000);
 };
 
-struct tpm_chip *tpm_chip_find_get(struct tpm_chip *chip);
+struct tpm_chip *tpm_get_ops(struct tpm_chip *chip);
 __must_check int tpm_try_get_ops(struct tpm_chip *chip);
 void tpm_put_ops(struct tpm_chip *chip);
 
diff --git a/drivers/char/tpm/tpm-chip.c b/drivers/char/tpm/tpm-chip.c
index 0a62c19937b6..4e83695af068 100644
--- a/drivers/char/tpm/tpm-chip.c
+++ b/drivers/char/tpm/tpm-chip.c
@@ -81,7 +81,7 @@ void tpm_put_ops(struct tpm_chip *chip)
 EXPORT_SYMBOL_GPL(tpm_put_ops);
 
 /**
  * tpm_chip_find_get() - find and reserve a TPM chip
  * @chip:      a &struct tpm_chip instance, %NULL for the default chip
  *
  * Finds a TPM chip and reserves its class device and operations. The chip must
@@ -92,7 +92,7 @@ EXPORT_SYMBOL_GPL(tpm_put_ops);
  * %NULL if a chip is not found.
  * %NULL if the chip is not available.
  */
-struct tpm_chip *tpm_chip_find_get(struct tpm_chip *chip)
+struct tpm_chip *tpm_get_ops(struct tpm_chip *chip)
 {
        struct tpm_chip *res = NULL;
        int chip_num = 0;
@@ -81,7 +81,7 @@ void tpm_put_ops(struct tpm_chip *chip)
 
 /**
- * tpm_chip_find_get() - find and reserve a TPM chip
+ * tpm_get_ops() - find and reserve a TPM chip
  * @chip:      a &struct tpm_chip instance, %NULL for the default chip
  *
-- 
2.13.6

Reply via email to